==> ejc-sealm-impl-3.0.0-20220112.033305-29-sources.jar: com/ejianc/business/sealm/bean/YzxhEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 印章销毁
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yzxh")
public class YzxhEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="yzbh_code")
    private java.lang.String yzbhCode; // 印章登记编号
    @TableField(value="yzlb_id")
    private java.lang.Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private java.lang.String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private java.lang.Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private java.lang.String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private java.lang.Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private java.lang.String yylxName; // 用印类型名称
    @TableField(value="kzzy")
    private java.lang.String kzzy; // 刻章字样
    @TableField(value="ssdw_id")
    private java.lang.Long ssdwId; // 所属单位id
    @TableField(value="ssdw_name")
    private java.lang.String ssdwName; // 所属单位名称
    @TableField(value="dqbgr_id")
    private java.lang.Long dqbgrId; // 当前保管人id
    @TableField(value="dqbgr_name")
    private java.lang.String dqbgrName; // 当前保管人名称
    @TableField(value="kzsj_time")
    private java.util.Date kzsjTime; // 刻制时间
    @TableField(value="baqk")
    private java.lang.Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @TableField(value="basj_time")
    private java.util.Date basjTime; // 备案时间
    @TableField(value="badw_id")
    private java.lang.Long badwId; // 备案单位id
    @TableField(value="badw_name")
    private java.lang.String badwName; // 备案单位名称
    @TableField(value="scdw_id")
    private java.lang.Long scdwId; // 生产单位id
    @TableField(value="scdw_name")
    private java.lang.String scdwName; // 生产单位名称
    @TableField(value="xhzrr_id")
    private java.lang.Long xhzrrId; // 销毁责任人id
    @TableField(value="xhzrr_name")
    private java.lang.String xhzrrName; // 销毁责任人名称
    @TableField(value="xh_date")
    private java.util.Date xhDate; // 销毁日期
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="begin_date")
    private java.util.Date beginDate; // 开始日期
    @TableField(value="end_date")
    private java.util.Date endDate; // 结束日期
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 编制人
    @TableField(value="update_user_name")
    private java.lang.String updateUserName; // 修改人



    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 印章登记编号
     */
    public java.lang.String getYzbhCode() {
        return yzbhCode;
    }

    /**
     * 印章登记编号
     */
    public void setYzbhCode(java.lang.String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    /**
     * 印章类别id
     */
    public java.lang.Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(java.lang.Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public java.lang.String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(java.lang.String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public java.lang.Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(java.lang.Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public java.lang.String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(java.lang.String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public java.lang.Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(java.lang.Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public java.lang.String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(java.lang.String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public java.lang.String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(java.lang.String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    public java.lang.Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    public void setSsdwId(java.lang.Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public java.lang.String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(java.lang.String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    public java.lang.Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    public void setDqbgrId(java.lang.Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public java.lang.String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(java.lang.String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public java.lang.Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(java.lang.Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public java.lang.Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(java.lang.Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public java.lang.String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(java.lang.String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public java.lang.Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(java.lang.Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public java.lang.String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(java.lang.String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 销毁责任人id
     */
    public java.lang.Long getXhzrrId() {
        return xhzrrId;
    }

    /**
     * 销毁责任人id
     */
    public void setXhzrrId(java.lang.Long xhzrrId) {
        this.xhzrrId = xhzrrId;
    }
    /**
     * 销毁责任人名称
     */
    public java.lang.String getXhzrrName() {
        return xhzrrName;
    }

    /**
     * 销毁责任人名称
     */
    public void setXhzrrName(java.lang.String xhzrrName) {
        this.xhzrrName = xhzrrName;
    }
    /**
     * 销毁日期
     */
    public java.util.Date getXhDate() {
        return xhDate;
    }

    /**
     * 销毁日期
     */
    public void setXhDate(java.util.Date xhDate) {
        this.xhDate = xhDate;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public java.lang.String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(java.lang.String updateUserName) {
        this.updateUserName = updateUserName;
    }
    
}

==> ejc-sealm-impl-3.0.0-20220614.100844-97-sources.jar: com/ejianc/business/sealm/bean/YzxhEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 印章销毁
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yzxh")
public class YzxhEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="yzbh_code")
    private java.lang.String yzbhCode; // 印章登记编号
    @TableField(value="yzlb_id")
    private java.lang.Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private java.lang.String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private java.lang.Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private java.lang.String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private java.lang.Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private java.lang.String yylxName; // 用印类型名称
    @TableField(value="kzzy")
    private java.lang.String kzzy; // 刻章字样
    @TableField(value="ssdw_id")
    private java.lang.Long ssdwId; // 所属单位id
    @TableField(value="ssdw_name")
    private java.lang.String ssdwName; // 所属单位名称
    @TableField(value="dqbgr_id")
    private java.lang.Long dqbgrId; // 当前保管人id
    @TableField(value="dqbgr_name")
    private java.lang.String dqbgrName; // 当前保管人名称
    @TableField(value="kzsj_time")
    private java.util.Date kzsjTime; // 刻制时间
    @TableField(value="baqk")
    private java.lang.Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @TableField(value="basj_time")
    private java.util.Date basjTime; // 备案时间
    @TableField(value="badw_id")
    private java.lang.Long badwId; // 备案单位id
    @TableField(value="badw_name")
    private java.lang.String badwName; // 备案单位名称
    @TableField(value="scdw_id")
    private java.lang.Long scdwId; // 生产单位id
    @TableField(value="scdw_name")
    private java.lang.String scdwName; // 生产单位名称
    @TableField(value="xhzrr_id")
    private java.lang.Long xhzrrId; // 销毁责任人id
    @TableField(value="xhzrr_name")
    private java.lang.String xhzrrName; // 销毁责任人名称
    @TableField(value="xh_date")
    private java.util.Date xhDate; // 销毁日期
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="begin_date")
    private java.util.Date beginDate; // 开始日期
    @TableField(value="end_date")
    private java.util.Date endDate; // 结束日期
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 编制人
    @TableField(value="update_user_name")
    private java.lang.String updateUserName; // 修改人
    @TableField(value="xhyy")
    private String xhyy; // 销毁原因



    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 印章登记编号
     */
    public java.lang.String getYzbhCode() {
        return yzbhCode;
    }

    /**
     * 印章登记编号
     */
    public void setYzbhCode(java.lang.String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    /**
     * 印章类别id
     */
    public java.lang.Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(java.lang.Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public java.lang.String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(java.lang.String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public java.lang.Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(java.lang.Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public java.lang.String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(java.lang.String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public java.lang.Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(java.lang.Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public java.lang.String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(java.lang.String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public java.lang.String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(java.lang.String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    public java.lang.Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    public void setSsdwId(java.lang.Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public java.lang.String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(java.lang.String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    public java.lang.Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    public void setDqbgrId(java.lang.Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public java.lang.String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(java.lang.String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public java.lang.Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(java.lang.Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public java.lang.Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(java.lang.Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public java.lang.String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(java.lang.String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public java.lang.Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(java.lang.Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public java.lang.String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(java.lang.String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 销毁责任人id
     */
    public java.lang.Long getXhzrrId() {
        return xhzrrId;
    }

    /**
     * 销毁责任人id
     */
    public void setXhzrrId(java.lang.Long xhzrrId) {
        this.xhzrrId = xhzrrId;
    }
    /**
     * 销毁责任人名称
     */
    public java.lang.String getXhzrrName() {
        return xhzrrName;
    }

    /**
     * 销毁责任人名称
     */
    public void setXhzrrName(java.lang.String xhzrrName) {
        this.xhzrrName = xhzrrName;
    }
    /**
     * 销毁日期
     */
    public java.util.Date getXhDate() {
        return xhDate;
    }

    /**
     * 销毁日期
     */
    public void setXhDate(java.util.Date xhDate) {
        this.xhDate = xhDate;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public java.lang.String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(java.lang.String updateUserName) {
        this.updateUserName = updateUserName;
    }

    /**
     * 销毁原因
     */
    public String getXhyy() {
        return xhyy;
    }

    /**
     * 销毁原因
     */
    public void setXhyy(String xhyy) {
        this.xhyy = xhyy;
    }
    
}
